@@ -23,6 +23,7 @@ import json
 import ast
 from numbers import Number
 import re
+import pdb
 
 from docutils import nodes
 from docutils.parsers.rst import directives
@@ -39,54 +40,51 @@ from runestone.common import (
     RunestoneIdNode,
     get_node_line,
 )
+from runestone.common.xmlcommon import substitute_departure, substitute_visitor
+
+
+def noop(self, node):
+    pass
 
 
 def setup(app):
     app.add_directive("fillintheblank", FillInTheBlank)
     app.add_role("blank", BlankRole)
-    app.add_node(FITBNode, html=(visit_fitb_node, depart_fitb_node))
-    app.add_node(BlankNode, html=(visit_blank_node, depart_blank_node))
+    app.add_node(FITBNode, html=(visit_fitb_html, depart_fitb_html),
+                 xml=(visit_fitb_xml, depart_fitb_xml))
+    app.add_node(BlankNode, html=(visit_blank_html, depart_blank_html))
     app.add_node(
-        FITBFeedbackNode, html=(visit_fitb_feedback_node, depart_fitb_feedback_node)
+        FITBFeedbackNode, html=(visit_fitb_feedback_html, depart_fitb_feedback_html),
+        xml=(noop, noop)
     )
 
     app.add_config_value("fitb_div_class", "runestone", "html")
 
 
 class FITBNode(nodes.General, nodes.Element, RunestoneIdNode):
-    def __init__(self, content, **kwargs):
-        """
-
-        Arguments:
-        - `self`:
-        - `content`:
-        """
-        super(FITBNode, self).__init__(**kwargs)
-        self.runestone_options = content
-        # Create a data structure of feedback.
-        self.feedbackArray = []
+    pass
 
 
-def visit_fitb_node(self, node):
+def visit_fitb_html(self, node):
 
-    node.delimiter = "_start__{}_".format(node.runestone_options["divid"])
-    self.body.append(node.delimiter)
+    node["delimiter"] = "_start__{}_".format(node["runestone_options"]["divid"])
+    self.body.append(node["delimiter"])
 
-    res = node.template_start % node.runestone_options
+    res = node["template_start"] % node["runestone_options"]
     self.body.append(res)
 
 
-def depart_fitb_node(self, node):
+def depart_fitb_html(self, node):
     # If there were fewer blanks than feedback items, add blanks at the end of the question.
     blankCount = 0
     for _ in node.traverse(BlankNode):
         blankCount += 1
-    while blankCount < len(node.feedbackArray):
-        visit_blank_node(self, None)
+    while blankCount < len(node["feedbackArray"]):
+        visit_blank_html(self, None)
         blankCount += 1
 
     # Warn if there are fewer feedback items than blanks.
-    if len(node.feedbackArray) < blankCount:
+    if len(node["feedbackArray"]) < blankCount:
         # Taken from the example in the `logging API <http://www.sphinx-doc.org/en/stable/extdev/logging.html#logging-api>`_.
         logger = logging.getLogger(__name__)
         logger.warning(
@@ -94,29 +92,118 @@ def depart_fitb_node(self, node):
         )
 
     # Generate the HTML.
-    json_feedback = json.dumps(node.feedbackArray)
+    json_feedback = json.dumps(node["feedbackArray"])
     # Some nodes (for example, those in a timed node) have their ``document == None``. Find a valid ``document``.
     node_with_document = node
     while not node_with_document.document:
         node_with_document = node_with_document.parent
-    # Supply client-side grading info if we're not grading on the server.
-    node.runestone_options["json"] = (
-        "false"
-        if node_with_document.document.settings.env.config.runestone_server_side_grading
-        else json_feedback
-    )
-    res = node.template_end % node.runestone_options
+    # Supply grading info (the ``json_feedback``) to the client if we're not grading on the server.
+    ssg = node_with_document.document.settings.env.config.runestone_server_side_grading
+    node["runestone_options"]["json"] = "false" if ssg else json_feedback
+    res = node["template_end"] % node["runestone_options"]
     self.body.append(res)
 
     # add HTML to the Database and clean up
     addHTMLToDB(
-        node.runestone_options["divid"],
-        node.runestone_options["basecourse"],
-        "".join(self.body[self.body.index(node.delimiter) + 1 :]),
-        json_feedback,
+        node["runestone_options"]["divid"],
+        node["runestone_options"]["basecourse"],
+        "".join(self.body[self.body.index(node["delimiter"]) + 1 :]),
+        # Either provide grading info to enable server-side grading or pass ``None`` to select client-side grading.
+        json_feedback if ssg else None,
     )
 
-    self.body.remove(node.delimiter)
+    self.body.remove(node["delimiter"])
+
+# <exercise>
+#     <title>Fill-In, Integer Answer</title>
+
+#     <statement>
+#         <p>The game of bowling uses <var/> pins that you try to knock down.</p>
+#     </statement>
+#     <setup>
+#         <var>
+#             <condition number="10">
+#                 <feedback>
+#                     <p>Arranged in a triangle, there are <m>1+2+3+4 = 10</m> pins, a so-called <term>triangular</term> number.</p>
+#                 </feedback>
+#             </condition>
+#             <condition number="16">
+#                 <feedback>
+#                     <p><em>Close</em>! You may have used hexadecimal notation, when you did not really mean to.</p>
+#                 </feedback>
+#             </condition>
+#             <condition string=".*">
+#                 <feedback>
+#                     <p>Incorrect.</p>
+#                 </feedback>
+#             </condition>
+#         </var>
+#     </setup>
+# </exercise>
+
+
+def visit_fitb_xml(self, node):
+
+    TEMPLATE_START = """
+        <exercise>
+            <statement>
+    """
+    self.output.append(TEMPLATE_START)
+    node.private_children = node.children[1:]
+    stmt = str(node.children[0])
+    stmt = re.sub(r"<problematic.*?</problematic>", "<var />", stmt)
+    neededBlanks = len(node["runestone_options"]["pattlist"])
+    numBlanks = stmt.count("<var />")
+    diff = neededBlanks - numBlanks
+    if diff > 0:
+        stmt = stmt[0:stmt.rfind("</paragraph>")]
+        for i in range(diff):
+            stmt += " <var /> "
+        stmt += " </paragraph>"
+    node.children = []
+    self.output.append(stmt)
+    self.output.append("</statement>")
+
+
+def depart_fitb_xml(self, node):
+
+    # pattlist = node["runestone_options"]["pattlist"]  # answer patterns
+    # flist = node["runestone_options"]["flist"]  # feedback
+    # for _ in pattlist:
+    #     blankCount += 1
+    # while blankCount < len(flist):
+    #     visit_blank_xml(self, None)
+    #     blankCount += 1
+
+    self.output.append("<setup>")
+    # Walk the children of node
+    # child 0 is the statement
+    # children 1..N are the feedbacks
+    #    each of these children will have an atribute called blankfeedbackdict which is the match for this
+    #    each child will have a child/children that is the actual feedback we want to supply
+    #
+
+    for var in range(len(node["runestone_options"]["pattlist"])):
+        self.output.append("<var>")
+
+        for ans in range(len(node["runestone_options"]["pattlist"][var])):
+            child = node.private_children.pop(0)
+            if "blankfeedbackdict" in child:
+                rx = child["blankfeedbackdict"]
+                if "number" in rx:
+                    self.output.append(f"""<condition number="{rx['number']}">""")
+                else:
+                    self.output.append(f"""<condition string="{rx['regex']}">""")
+                fb = ""
+                for p in child.children:
+                    fb += str(p)
+                self.output.append(f"<feedback>{fb}</feedback>")
+                self.output.append("</condition>")
+            else:
+                self.output.append(str(child))
+        self.output.append("</var>")
+    self.output.append("</setup>")
+    self.output.append("</exercise>")
 
 
 class FillInTheBlank(RunestoneIdDirective):
@@ -156,7 +243,7 @@ class FillInTheBlank(RunestoneIdDirective):
         super(FillInTheBlank, self).run()
 
         TEMPLATE_START = """
-        <div class="%(divclass)s">
+        <div class="%(divclass)s %(optclass)s">
         <div data-component="fillintheblank" data-question_label="%(question_label)s" id="%(divid)s" %(optional)s style="visibility: hidden;">
             """
 
@@ -171,19 +258,20 @@ class FillInTheBlank(RunestoneIdDirective):
 
         addQuestionToDB(self)
 
-        fitbNode = FITBNode(self.options, rawsource=self.block_text)
-        fitbNode.source, fitbNode.line = self.state_machine.get_source_and_line(
+        fitbNode = FITBNode()
+        fitbNode["runestone_options"] = self.options
+        fitbNode["feedbackArray"] = []
+        fitbNode["source"], fitbNode["line"] = self.state_machine.get_source_and_line(
             self.lineno
         )
-        fitbNode.template_start = TEMPLATE_START
-        fitbNode.template_end = TEMPLATE_END
+        fitbNode["template_start"] = TEMPLATE_START
+        fitbNode["template_end"] = TEMPLATE_END
 
         self.updateContent()
 
         self.state.nested_parse(self.content, self.content_offset, fitbNode)
         env = self.state.document.settings.env
         self.options["divclass"] = env.config.fitb_div_class
-
         # Expected _`structure`, with assigned variable names and transformations made:
         #
         # .. code-block::
@@ -245,6 +333,8 @@ class FillInTheBlank(RunestoneIdDirective):
                     get_node_line(feedback_bullet_list)
                 )
             )
+        # Thelength of feedbback_list_item gives us the number of blanks.
+        # the number of feedback is len(feedback_bullet_list.children[x].children[0].children)
         for feedback_list_item in feedback_bullet_list.children:
             assert isinstance(feedback_list_item, nodes.list_item)
             feedback_field_list = feedback_list_item[0]
@@ -285,9 +375,9 @@ class FillInTheBlank(RunestoneIdDirective):
                     regex = (
                         # The given regex must match the entire string, from the beginning (which may be preceded by whitespaces) ...
                         r"^\s*"
-                        +
+
                         # ... to the contents (where a single space in the provided pattern is treated as one or more whitespaces in the student's answer) ...
-                        feedback_field_name.rawsource.replace(" ", r"\s+")
+                        + feedback_field_name.rawsource.replace(" ", r"\s+")
                         # ... to the end (also with optional spaces).
                         + r"\s*$"
                     )
@@ -305,7 +395,6 @@ class FillInTheBlank(RunestoneIdDirective):
                             )
                         )
                 blankArray.append(blankFeedbackDict)
-
                 feedback_field_body = feedback_field[1]
                 assert isinstance(feedback_field_body, nodes.field_body)
                 # Append feedback for this answer to the end of the fitbNode.
@@ -314,13 +403,15 @@ class FillInTheBlank(RunestoneIdDirective):
                     *feedback_field_body.children,
                     **feedback_field_body.attributes
                 )
-                ffn.blankFeedbackDict = blankFeedbackDict
+                ffn["blankFeedbackDict"] = blankFeedbackDict
                 fitbNode += ffn
 
             # Add all the feedback for this blank to the feedbackArray.
-            fitbNode.feedbackArray.append(blankArray)
+            fitbNode["feedbackArray"].append(blankArray)
 
         maybeAddToAssignment(self)
+        fitbNode["runestone_options"]["pattlist"] = fitbNode["feedbackArray"][:]
+        fitbNode["runestone_options"]["flist"] = feedback_field_list[:]
 
         return [fitbNode]
 
@@ -358,11 +449,15 @@ class BlankNode(nodes.Inline, nodes.TextElement, RunestoneNode):
     pass
 
 
-def visit_blank_node(self, node):
+def visit_blank_html(self, node):
     self.body.append('<input type="text">')
 
 
-def depart_blank_node(self, node):
+def visit_blank_xml(self, node):
+    self.output.append('<p><var /></p>')
+
+
+def depart_blank_html(self, node):
     pass
 
 
@@ -371,14 +466,14 @@ class FITBFeedbackNode(nodes.General, nodes.Element, RunestoneNode):
     pass
 
 
-def visit_fitb_feedback_node(self, node):
+def visit_fitb_feedback_html(self, node):
     # Save the HTML generated thus far. Anything generated under this node will be placed in JSON.
     self.context.append(self.body)
     self.body = []
 
 
-def depart_fitb_feedback_node(self, node):
+def depart_fitb_feedback_html(self, node):
     # Place all the HTML generated for this node and its children into the feedbackArray.
-    node.blankFeedbackDict["feedback"] = "".join(self.body)
+    node["blankFeedbackDict"]["feedback"] = "".join(self.body)
     # Restore HTML generated thus far.
     self.body = self.context.pop()
